Module recorder

Module recorder 

Useful for use as delegate implementing Visit to keep track of all seen changes. Useful for debugging or printing primarily.

Structs

Recorder
A Visit implementation to record every observed change and keep track of the changed paths.

Enums

Change
A Change as observed by a call to visit(…), enhanced with the path affected by the change. Its similar to visit::Change but includes the path that changed.