pub trait Visit {
// Required methods
fn pop_front_tracked_path_and_set_current(&mut self);
fn push_back_tracked_path_component(&mut self, component: &BStr);
fn push_path_component(&mut self, component: &BStr);
fn pop_path_component(&mut self);
fn visit(&mut self, change: Change) -> Action;
}Expand description
A trait to allow responding to a traversal designed to figure out the changes to turn tree A into tree B.
Required Methods
Sourcefn pop_front_tracked_path_and_set_current(&mut self)
fn pop_front_tracked_path_and_set_current(&mut self)
Sets the full path path in front of the queue so future calls to push and pop components affect it instead.
Sourcefn push_back_tracked_path_component(&mut self, component: &BStr)
fn push_back_tracked_path_component(&mut self, component: &BStr)
Append a component to the end of a path, which may be empty.
Sourcefn push_path_component(&mut self, component: &BStr)
fn push_path_component(&mut self, component: &BStr)
Append a component to the end of a path, which may be empty.
Sourcefn pop_path_component(&mut self)
fn pop_path_component(&mut self)
Removes the last component from the path, which may leave it empty.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".